==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebActiveNodeChangeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebActiveNodeChangeEventArgsDetailDescriptionMetadata } from "./WebActiveNodeChangeEventArgsDetailDescriptionMetadata";
import { WebActiveNodeChangeEventArgsDescription } from "./WebActiveNodeChangeEventArgsDescription";
/**
 * @hidden
 */
export let WebActiveNodeChangeEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebActiveNodeChangeEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebActiveNodeChangeEventArgsDescriptionMetadata.a == null) {
                WebActiveNodeChangeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebActiveNodeChangeEventArgsDescriptionMetadata.c(WebActiveNodeChangeEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebActiveNodeChangeEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebActiveNodeChangeEventArgsDescriptionMetadata.a);
            WebActiveNodeChangeEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ActiveNodeChangeEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("Detail", "ExportedType:WebActiveNodeChangeEventArgsDetail");
        }
        static d(a) {
            WebActiveNodeChangeEventArgsDescriptionMetadata.b(a);
            a.aa("WebActiveNodeChangeEventArgs", () => new WebActiveNodeChangeEventArgsDescription());
            a.z("WebActiveNodeChangeEventArgs", WebActiveNodeChangeEventArgsDescriptionMetadata.a);
        }
    }
    WebActiveNodeChangeEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebActiveNodeChangeEventArgsDescriptionMetadata, 'WebActiveNodeChangeEventArgsDescriptionMetadata');
    WebActiveNodeChangeEventArgsDescriptionMetadata.a = null;
    return WebActiveNodeChangeEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebActiveNodeChangeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebActiveNodeChangeEventArgsDetailDescriptionMetadata } from "./WebActiveNodeChangeEventArgsDetailDescriptionMetadata";
import { WebActiveNodeChangeEventArgsDescription } from "./WebActiveNodeChangeEventArgsDescription";
/**
 * @hidden
 */
export let WebActiveNodeChangeEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebActiveNodeChangeEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebActiveNodeChangeEventArgsDescriptionMetadata.a == null) {
                WebActiveNodeChangeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebActiveNodeChangeEventArgsDescriptionMetadata.c(WebActiveNodeChangeEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebActiveNodeChangeEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebActiveNodeChangeEventArgsDescriptionMetadata.a);
            WebActiveNodeChangeEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ActiveNodeChangeEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebActiveNodeChangeEventArgsDetail");
        }
        static d(a) {
            WebActiveNodeChangeEventArgsDescriptionMetadata.b(a);
            a.ac("WebActiveNodeChangeEventArgs", () => new WebActiveNodeChangeEventArgsDescription());
            a.ab("WebActiveNodeChangeEventArgs", WebActiveNodeChangeEventArgsDescriptionMetadata.a);
        }
    }
    WebActiveNodeChangeEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebActiveNodeChangeEventArgsDescriptionMetadata, 'WebActiveNodeChangeEventArgsDescriptionMetadata');
    WebActiveNodeChangeEventArgsDescriptionMetadata.a = null;
    return WebActiveNodeChangeEventArgsDescriptionMetadata;
})();
